==> nautilus-1.1.2.tar.bz2: nautilus-1.1.2/src/nautilus-signaller.c <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/*
 * Nautilus
 *
 * Copyright (C) 1999, 2000 Eazel, Inc.
 *
 * Nautilus is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: John Sullivan <sullivan@eazel.com>
 */

/* nautilus-signaller.h: Class to manage nautilus-wide signals that don't
 * correspond to any particular object.
 */

#include <config.h>
#include "nautilus-signaller.h"

#include <gtk/gtksignal.h>
#include <eel/eel-gtk-macros.h>

typedef GtkObject NautilusSignaller;
typedef GtkObjectClass NautilusSignallerClass;

enum {
	HISTORY_LIST_CHANGED,
	EMBLEMS_CHANGED,
	LAST_SIGNAL
};

static guint signals[LAST_SIGNAL];

static GtkObject *global_signaller = NULL;

static GtkType nautilus_signaller_get_type         (void);
static void    nautilus_signaller_class_init (gpointer klass);
static void    nautilus_signaller_init       (gpointer object,
						    gpointer klass);

EEL_CLASS_BOILERPLATE (NautilusSignaller,
				   nautilus_signaller,
				   GTK_TYPE_OBJECT)

static void
nautilus_signaller_class_init (gpointer klass)
{
	GtkObjectClass *object_class;

	object_class = GTK_OBJECT_CLASS (klass);
	
	signals[HISTORY_LIST_CHANGED] =
		g_signal_new ("history_list_changed",
		              G_TYPE_FROM_CLASS (object_class),
		              G_SIGNAL_RUN_LAST,
		              0,
		              NULL, NULL,
		              gtk_marshal_NONE__NONE,
		              G_TYPE_NONE, 0);
	signals[EMBLEMS_CHANGED] =
		g_signal_new ("emblems_changed",
		              G_TYPE_FROM_CLASS (object_class),
		              G_SIGNAL_RUN_LAST,
		              0,
		              NULL, NULL,
		              gtk_marshal_NONE__NONE,
		              G_TYPE_NONE, 0);
}

static void
nautilus_signaller_init (gpointer object, gpointer klass)
{
	/* placeholder to allow use of boilerplate macro */
}

static void
unref_global_signaller (void)
{
	g_object_unref (global_signaller);
}

GtkObject *
nautilus_signaller_get_current (void)
{
	if (global_signaller == NULL) {
		global_signaller = g_object_new (nautilus_signaller_get_type (), NULL);
		g_object_ref (global_signaller);
		gtk_object_sink (GTK_OBJECT (global_signaller));
		g_atexit (unref_global_signaller);
	}

	return global_signaller;
}

==> nautilus-2.3.90.tar.bz2: nautilus-2.3.90/src/nautilus-signaller.c <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/*
 * Nautilus
 *
 * Copyright (C) 1999, 2000 Eazel, Inc.
 *
 * Nautilus is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: John Sullivan <sullivan@eazel.com>
 */

/* nautilus-signaller.h: Class to manage nautilus-wide signals that don't
 * correspond to any particular object.
 */

#include <config.h>
#include "nautilus-signaller.h"

#include <eel/eel-debug.h>
#include <libgnome/gnome-macros.h>

typedef GObject NautilusSignaller;
typedef GObjectClass NautilusSignallerClass;

enum {
	HISTORY_LIST_CHANGED,
	EMBLEMS_CHANGED,
	LAST_SIGNAL
};

static guint signals[LAST_SIGNAL];

static GType nautilus_signaller_get_type (void);

GNOME_CLASS_BOILERPLATE (NautilusSignaller, nautilus_signaller,
			 GObject, G_TYPE_OBJECT)

GObject *
nautilus_signaller_get_current (void)
{
	static GObject *global_signaller = NULL;

	if (global_signaller == NULL) {
		global_signaller = g_object_new (nautilus_signaller_get_type (), NULL);
		eel_debug_call_at_shutdown_with_data (g_object_unref, global_signaller);
	}

	return global_signaller;
}

static void
nautilus_signaller_instance_init (NautilusSignaller *signaller)
{
}

static void
nautilus_signaller_class_init (NautilusSignallerClass *class)
{
	signals[HISTORY_LIST_CHANGED] =
		g_signal_new ("history_list_changed",
		              G_TYPE_FROM_CLASS (class),
		              G_SIGNAL_RUN_LAST,
		              0,
		              NULL, NULL,
		              g_cclosure_marshal_VOID__VOID,
		              G_TYPE_NONE, 0);
	signals[EMBLEMS_CHANGED] =
		g_signal_new ("emblems_changed",
		              G_TYPE_FROM_CLASS (class),
		              G_SIGNAL_RUN_LAST,
		              0,
		              NULL, NULL,
		              g_cclosure_marshal_VOID__VOID,
		              G_TYPE_NONE, 0);
}
